maint: prefer HTTPS to HTTP, FTP in URLs
[debian/gzip] / gzip.c
diff --git a/gzip.c b/gzip.c
index 707a190943995df1a93703fa968308c9c9384438..a4717aaad8be2fa7723f450e2ab1d094c995fec3 100644 (file)
--- a/gzip.c
+++ b/gzip.c
@@ -32,7 +32,7 @@ static char const *const license_msg[] = {
 "Copyright (C) 2016 Free Software Foundation, Inc.",
 "Copyright (C) 1993 Jean-loup Gailly.",
 "This is free software.  You may redistribute copies of it under the terms of",
-"the GNU General Public License <http://www.gnu.org/licenses/gpl.html>.",
+"the GNU General Public License <https://www.gnu.org/licenses/gpl.html>.",
 "There is NO WARRANTY, to the extent permitted by law.",
 0};
 
@@ -194,7 +194,7 @@ static char *env;            /* contents of GZIP env variable */
 static char const *z_suffix; /* default suffix (can be set with --suffix) */
 static size_t z_len;         /* strlen(z_suffix) */
 
/* The original time stamp (modification time).  Its tv_nsec component
    is negative if the original time is unknown or is out of time_t
    range; the latter can happen on hosts with 32-bit signed time_t
    because the gzip format's MTIME is 32-bit unsigned.  */
@@ -365,8 +365,8 @@ local void help()
  "  -m                do not save or restore the original modification time",
  "  -M, --time        save or restore the original modification time",
 #endif
- "  -n, --no-name     do not save or restore the original name and time stamp",
- "  -N, --name        save or restore the original name and time stamp",
+ "  -n, --no-name     do not save or restore the original name and timestamp",
+ "  -N, --name        save or restore the original name and timestamp",
  "  -q, --quiet       suppress all warnings",
 #if ! NO_DIR
  "  -r, --recursive   operate recursively on directories",
@@ -599,7 +599,7 @@ int main (int argc, char **argv)
         case '4' + ENV_OPTION:  case '5' + ENV_OPTION:  case '6' + ENV_OPTION:
         case '7' + ENV_OPTION:  case '8' + ENV_OPTION:  case '9' + ENV_OPTION:
             optc -= ENV_OPTION;
-            /* Fall through.  */
+            FALLTHROUGH;
         case '1':  case '2':  case '3':  case '4':
         case '5':  case '6':  case '7':  case '8':  case '9':
             level = optc - '0';
@@ -752,7 +752,7 @@ local void treat_stdin()
     strcpy(ifname, "stdin");
     strcpy(ofname, "stdout");
 
/* Get the file's time stamp and size.  */
     if (fstat (STDIN_FILENO, &istat) != 0)
       {
         progerror ("standard input");
@@ -1479,7 +1479,7 @@ local int get_method(in)
     uch magic[10]; /* magic header */
     int imagic0;   /* first magic byte or EOF */
     int imagic1;   /* like magic[1], but can represent EOF */
-    ulg stamp;     /* time stamp */
+    ulg stamp;     /* timestamp */
 
     /* If --force and --stdout, zcat == cat, so do not complain about
      * premature end of file: use try_byte instead of get_byte.
@@ -1932,7 +1932,7 @@ local void copy_stat(ifstat)
     if (fdutimens (ofd, ofname, timespec) == 0)
       {
         if (restoring && 1 < verbose) {
-            fprintf(stderr, "%s: time stamp restored\n", ofname);
+            fprintf(stderr, "%s: timestamp restored\n", ofname);
         }
       }
     else
@@ -194,7 +194,7 @@ static char *env;            /* contents of GZIP env variable */
 static size_t z_len;         /* strlen(z_suffix) */
 
-/* The original time stamp (modification time).  Its tv_nsec component
+/* The original timestamp (modification time).  Its tv_nsec component
    is negative if the original time is unknown or is out of time_t
    range; the latter can happen on hosts with 32-bit signed time_t
@@ -752,7 +752,7 @@ local void treat_stdin()
     strcpy(ofname, "stdout");
 
-    /* Get the file's time stamp and size.  */
+    /* Get the file's timestamp and size.  */
     if (fstat (STDIN_FILENO, &istat) != 0)
       {